@@ -1,6 +1,6 @@
-package Locale::CLDR::Af::Any;
+package Locale::CLDR::Af::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  6:08:27 pm GMT
+#	on Mon 21 Apr 10:09:19 pm GMT
 
 use v5.18;
 use mro 'c3';
