@@ -1,6 +1,6 @@
-package Locale::CLDR::Cy::Any;
+package Locale::CLDR::Cy::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:26:32 pm GMT
+#	on Mon 21 Apr 10:35:42 pm GMT
 
 use v5.18;
 use mro 'c3';
