@@ -1,6 +1,6 @@
-package Locale::CLDR::Dje::Any;
+package Locale::CLDR::Dje::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:27:39 pm GMT
+#	on Mon 21 Apr 10:38:59 pm GMT
 
 use v5.18;
 use mro 'c3';
