@@ -1,6 +1,6 @@
-package Locale::CLDR::Fy::Any;
+package Locale::CLDR::Fy::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:39:41 pm GMT
+#	on Mon 21 Apr 11:01:52 pm GMT
 
 use v5.18;
 use mro 'c3';
