@@ -1,6 +1,6 @@
-package Locale::CLDR::Gl::Any;
+package Locale::CLDR::Gl::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:40:19 pm GMT
+#	on Mon 21 Apr 11:03:53 pm GMT
 
 use v5.18;
 use mro 'c3';
