@@ -1,6 +1,6 @@
-package Locale::CLDR::Gsw::Any;
+package Locale::CLDR::Gsw::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:40:27 pm GMT
+#	on Mon 21 Apr 11:04:58 pm GMT
 
 use v5.18;
 use mro 'c3';
