@@ -1,6 +1,6 @@
-package Locale::CLDR::Gu::Any;
+package Locale::CLDR::Gu::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:42:15 pm GMT
+#	on Mon 21 Apr 11:07:04 pm GMT
 
 use v5.18;
 use mro 'c3';
