@@ -1,6 +1,6 @@
-package Locale::CLDR::Ig::Any;
+package Locale::CLDR::Ig::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:49:35 pm GMT
+#	on Mon 21 Apr 11:19:03 pm GMT
 
 use v5.18;
 use mro 'c3';
