@@ -1,6 +1,6 @@
-package Locale::CLDR::Jgo::Any;
+package Locale::CLDR::Jgo::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:52:35 pm GMT
+#	on Mon 21 Apr 11:24:46 pm GMT
 
 use v5.18;
 use mro 'c3';
