@@ -1,6 +1,6 @@
-package Locale::CLDR::Kam::Any;
+package Locale::CLDR::Kam::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:54:23 pm GMT
+#	on Mon 21 Apr 11:27:26 pm GMT
 
 use v5.18;
 use mro 'c3';
