@@ -1,6 +1,6 @@
-package Locale::CLDR::Kl::Any;
+package Locale::CLDR::Kl::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:56:16 pm GMT
+#	on Mon 21 Apr 11:29:48 pm GMT
 
 use v5.18;
 use mro 'c3';
