@@ -1,6 +1,6 @@
-package Locale::CLDR::Mua::Any;
+package Locale::CLDR::Mua::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:39:16 pm GMT
+#	on Tue 22 Apr 12:00:13 am GMT
 
 use v5.18;
 use mro 'c3';
