@@ -1,6 +1,6 @@
-package Locale::CLDR::Naq::Any;
+package Locale::CLDR::Naq::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:40:59 pm GMT
+#	on Tue 22 Apr 12:02:24 am GMT
 
 use v5.18;
 use mro 'c3';
