@@ -1,6 +1,6 @@
-package Locale::CLDR::Nyn::Any;
+package Locale::CLDR::Nyn::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:44:04 pm GMT
+#	on Tue 22 Apr 12:09:14 am GMT
 
 use v5.18;
 use mro 'c3';
