@@ -1,6 +1,6 @@
-package Locale::CLDR::Pl::Any;
+package Locale::CLDR::Pl::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:46:39 pm GMT
+#	on Tue 22 Apr 12:13:03 am GMT
 
 use v5.18;
 use mro 'c3';
