@@ -1,6 +1,6 @@
-package Locale::CLDR::Seh::Any;
+package Locale::CLDR::Seh::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:52:29 pm GMT
+#	on Tue 22 Apr 12:23:38 am GMT
 
 use v5.18;
 use mro 'c3';
