@@ -1,6 +1,6 @@
-package Locale::CLDR::Wal::Any;
+package Locale::CLDR::Wal::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  9:12:42 pm GMT
+#	on Tue 22 Apr 12:57:13 am GMT
 
 use v5.18;
 use mro 'c3';
